@@ -89,8 +89,7 @@ GMLDfct=function(gdat,simparams){
      if(is.null(simparams$cl)) { # no cluster: use lapply 
        unlist(lapply(gdat,parfile.fitLD))
      } else { # can use clusterApplyLB to distribute work over cluster
-       require(parallel)
-       unlist(clusterApplyLB(simparams$cl,gdat,parfile.fitLD))
+       unlist(parallel::clusterApplyLB(simparams$cl,gdat,parfile.fitLD))
      }
 }
   
@@ -175,8 +174,7 @@ gendrp=function(gdat,peddat,nreps,simparams){
     if(is.null(simparams$cl)) {
       snpmatlist<-lapply(gdat,doGeneDrops,peddat,nreps,simparams)
     } else {
-      require(parallel)
-      snpmatlist<-clusterApply(simparams$cl,gdat,doGeneDrops,peddat,nreps,simparams)
+      snpmatlist<-parallel::clusterApply(simparams$cl,gdat,doGeneDrops,peddat,nreps,simparams)
     }
         
     # cbind results into one big snp.matrix object
